Welcome to Orange3-Prototypes documentation!
============================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/contingency-table
   widgets/correlations
   widgets/enklik-anketa
   widgets/neighbors
   widgets/parallel-coordinates
   widgets/stacking
   widgets/feature-statistics
   widgets/select-by-data-index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
